CompileOptions

Struct CompileOptions 

pub struct CompileOptions {
Show 20 fields pub save_llvm_ir: bool, pub save_ebpf: bool, pub save_ast: bool, pub binary_path_hint: Option<String>, pub target_binary_path: Option<String>, pub ringbuf_size: u64, pub proc_module_offsets_max_entries: u64, pub backtrace_unwind_rows_max_entries: u32, pub perf_page_count: u32, pub event_map_type: EventMapType, pub mem_dump_cap: u32, pub compare_cap: u32, pub max_trace_event_size: u32, pub backtrace_depth: u8, pub selected_index: Option<usize>, pub pid_filter_spec: Option<PidFilterSpec>, pub special_pid_ns: Option<PidNamespaceId>, pub proc_offsets_pid_ns: Option<PidNamespaceId>, pub input_pid: Option<u32>, pub runtime_capabilities: RuntimeCapabilities,
}
Compilation options including save options and eBPF map configuration

Fields

save_llvm_ir: boolsave_ebpf: boolsave_ast: boolbinary_path_hint: Option<String>target_binary_path: Option<String>

Explicit -t target path. When present, trace target resolution is scoped to this module even if DWARF was loaded from a -p PID.

ringbuf_size: u64proc_module_offsets_max_entries: u64backtrace_unwind_rows_max_entries: u32

Fixed capacity for DWARF compact CFI rows used by bt.

perf_page_count: u32event_map_type: EventMapTypemem_dump_cap: u32

Max bytes to read per memory-dump argument (format {:x}/{:s}).

compare_cap: u32

Max bytes to compare for string/memory comparisons (strncmp/starts_with/memcmp)

max_trace_event_size: u32

Max total bytes in a single trace event (used for PerfEventArray accumulation buffer size).

backtrace_depth: u8

Max DWARF-unwound frames captured by each bt/backtrace instruction.

selected_index: Option<usize>

Optional single-address filter: if set, only the Nth (1-based) address resolved for a target will be compiled. When None, compile all.

pid_filter_spec: Option<PidFilterSpec>

Optional PID filter strategy override. When None, compiler falls back to HostTgid using compile_script(pid).

special_pid_ns: Option<PidNamespaceId>

Optional PID namespace context used by special vars like $pid/$tid. This is independent of PID filtering and is primarily for -t mode.

proc_offsets_pid_ns: Option<PidNamespaceId>

Optional PID namespace context used by proc_module_offsets lookups.

In -p mode this only switches to the target PID-namespace view when GhostScope has an explicit namespace-local target PID that can be aliased back to the /proc key used to populate proc_module_offsets. Otherwise it stays on GhostScope’s current /proc-visible PID view.

In -t mode we continue to use GhostScope’s own /proc view, because offsets are discovered from /proc/<pid>/maps in that namespace.

input_pid: Option<u32>

Optional original -p input PID for $input_pid. This is only available in -p mode.

runtime_capabilities: RuntimeCapabilities

Runtime/backend capabilities used to validate DWARF variable read plans.